@@ -35,6 +35,9 @@ from .queries import (
     ALL_FRAGMENTS,
     CREATE_ISSUE_MUTATION,
     CREATE_LABEL_MUTATION,
+    GET_ISSUE_STATUS_QUERY,
+    LIST_CYCLES_QUERY,
+    LIST_ISSUE_STATUSES_QUERY,
     LIST_ISSUES_QUERY,
     SEARCH_ISSUES_QUERY,
     UPDATE_ISSUE_MUTATION,
@@ -269,6 +272,69 @@ class LinearAdapter(BaseAdapter[Task]):
 
         return []
 
+    async def get_project(self, project_id: str) -> dict[str, Any] | None:
+        """Get a Linear project by ID using direct query.
+
+        This method uses Linear's direct project(id:) GraphQL query for efficient lookups.
+        Supports UUID, slugId, or short ID formats.
+
+        Args:
+            project_id: Project UUID, slugId, or short ID
+
+        Returns:
+            Project dict with fields (id, name, description, state, etc.) or None if not found
+
+        Examples:
+            - "a1b2c3d4-e5f6-7890-abcd-ef1234567890" (UUID)
+            - "crm-smart-monitoring-system-f59a41a96c52" (slugId)
+            - "6cf55cfcfad4" (short ID - 12 hex chars)
+
+        """
+        if not project_id:
+            return None
+
+        # Direct query using Linear's project(id:) endpoint
+        query = """
+            query GetProject($id: String!) {
+                project(id: $id) {
+                    id
+                    name
+                    description
+                    state
+                    slugId
+                    createdAt
+                    updatedAt
+                    url
+                    icon
+                    color
+                    targetDate
+                    startedAt
+                    completedAt
+                    teams {
+                        nodes {
+                            id
+                            name
+                            key
+                            description
+                        }
+                    }
+                }
+            }
+        """
+
+        try:
+            result = await self.client.execute_query(query, {"id": project_id})
+
+            if result.get("project"):
+                return result["project"]
+
+            # No match found
+            return None
+
+        except Exception:
+            # Linear returns error if project not found - return None instead of raising
+            return None
+
     async def _resolve_project_id(self, project_identifier: str) -> str | None:
         """Resolve project identifier (slug, name, short ID, or URL) to full UUID.
 
@@ -309,37 +375,100 @@ class LinearAdapter(BaseAdapter[Task]):
         if len(project_identifier) == 36 and project_identifier.count("-") == 4:
             return project_identifier
 
-        # Query all projects and search for matching slug, name, or slugId
+        # OPTIMIZATION: Try direct query first if it looks like a UUID, slugId, or short ID
+        # This is more efficient than listing all projects
+        should_try_direct_query = False
+
+        # Check if it looks like a short ID (exactly 12 hex characters)
+        if len(project_identifier) == 12 and all(
+            c in "0123456789abcdefABCDEF" for c in project_identifier
+        ):
+            should_try_direct_query = True
+
+        # Check if it looks like a slugId format (contains dashes and ends with 12 hex chars)
+        if "-" in project_identifier:
+            parts = project_identifier.rsplit("-", 1)
+            if len(parts) > 1:
+                potential_short_id = parts[1]
+                if len(potential_short_id) == 12 and all(
+                    c in "0123456789abcdefABCDEF" for c in potential_short_id
+                ):
+                    should_try_direct_query = True
+
+        # Try direct query first if identifier format suggests it might work
+        if should_try_direct_query:
+            try:
+                project = await self.get_project(project_identifier)
+                if project:
+                    return project["id"]
+            except Exception as e:
+                # Direct query failed - fall through to list-based search
+                logging.getLogger(__name__).debug(
+                    f"Direct project query failed for '{project_identifier}': {e}. "
+                    f"Falling back to listing all projects."
+                )
+
+        # FALLBACK: Query all projects with pagination support
+        # This is less efficient but handles name-based lookups and edge cases
         query = """
-            query GetProjects {
-                projects(first: 100) {
+            query GetProjects($first: Int!, $after: String) {
+                projects(first: $first, after: $after) {
                     nodes {
                         id
                         name
                         slugId
                     }
+                    pageInfo {
+                        hasNextPage
+                        endCursor
+                    }
                 }
             }
         """
 
         try:
-            result = await self.client.execute_query(query, {})
-            projects = result.get("projects", {}).get("nodes", [])
+            # Fetch all projects across multiple pages
+            all_projects = []
+            has_next_page = True
+            after_cursor = None
+
+            while has_next_page:
+                variables = {"first": 100}
+                if after_cursor:
+                    variables["after"] = after_cursor
+
+                result = await self.client.execute_query(query, variables)
+                projects_data = result.get("projects", {})
+                page_projects = projects_data.get("nodes", [])
+                page_info = projects_data.get("pageInfo", {})
+
+                all_projects.extend(page_projects)
+                has_next_page = page_info.get("hasNextPage", False)
+                after_cursor = page_info.get("endCursor")
 
             # Search for match by slug, slugId, name (case-insensitive)
             project_lower = project_identifier.lower()
-            for project in projects:
+            for project in all_projects:
                 # Check if identifier matches slug pattern (extracted from slugId)
                 slug_id = project.get("slugId", "")
                 if slug_id:
                     # slugId format: "crm-smart-monitoring-system-f59a41a96c52"
+                    # Linear short IDs are always exactly 12 hexadecimal characters
                     # Extract both the slug part and short ID
                     if "-" in slug_id:
-                        parts = slug_id.rsplit(
-                            "-", 1
-                        )  # Split from right to get last part
-                        slug_part = parts[0]  # "crm-smart-monitoring-system"
-                        short_id = parts[1] if len(parts) > 1 else ""  # "f59a41a96c52"
+                        parts = slug_id.rsplit("-", 1)
+                        potential_short_id = parts[1] if len(parts) > 1 else ""
+
+                        # Validate it's exactly 12 hex characters
+                        if len(potential_short_id) == 12 and all(
+                            c in "0123456789abcdefABCDEF" for c in potential_short_id
+                        ):
+                            slug_part = parts[0]
+                            short_id = potential_short_id
+                        else:
+                            # Fallback: treat entire slugId as slug if last part isn't valid
+                            slug_part = slug_id
+                            short_id = ""
 
                         # Match full slugId, slug part, or short ID
                         if (
@@ -361,6 +490,92 @@ class LinearAdapter(BaseAdapter[Task]):
                 f"Failed to resolve project '{project_identifier}': {e}"
             ) from e
 
+    async def _validate_project_team_association(
+        self, project_id: str, team_id: str
+    ) -> tuple[bool, list[str]]:
+        """Check if team is associated with project.
+
+        Args:
+            project_id: Linear project UUID
+            team_id: Linear team UUID
+
+        Returns:
+            Tuple of (is_associated, list_of_project_team_ids)
+
+        """
+        project = await self.get_project(project_id)
+        if not project:
+            return False, []
+
+        # Extract team IDs from project's teams
+        project_team_ids = [
+            team["id"] for team in project.get("teams", {}).get("nodes", [])
+        ]
+
+        return team_id in project_team_ids, project_team_ids
+
+    async def _ensure_team_in_project(self, project_id: str, team_id: str) -> bool:
+        """Add team to project if not already associated.
+
+        Args:
+            project_id: Linear project UUID
+            team_id: Linear team UUID to add
+
+        Returns:
+            True if successful, False otherwise
+
+        """
+        # First check current association
+        is_associated, existing_team_ids = (
+            await self._validate_project_team_association(project_id, team_id)
+        )
+
+        if is_associated:
+            return True  # Already associated, nothing to do
+
+        # Add team to project by updating project's teamIds
+        update_query = """
+            mutation UpdateProject($id: String!, $input: ProjectUpdateInput!) {
+                projectUpdate(id: $id, input: $input) {
+                    success
+                    project {
+                        id
+                        teams {
+                            nodes {
+                                id
+                                name
+                            }
+                        }
+                    }
+                }
+            }
+        """
+
+        # Include existing teams + new team
+        all_team_ids = existing_team_ids + [team_id]
+
+        try:
+            result = await self.client.execute_mutation(
+                update_query, {"id": project_id, "input": {"teamIds": all_team_ids}}
+            )
+            success = result.get("projectUpdate", {}).get("success", False)
+
+            if success:
+                logging.getLogger(__name__).info(
+                    f"Successfully added team {team_id} to project {project_id}"
+                )
+            else:
+                logging.getLogger(__name__).warning(
+                    f"Failed to add team {team_id} to project {project_id}"
+                )
+
+            return success
+        except Exception as e:
+            logging.getLogger(__name__).error(
+                f"Error adding team {team_id} to project {project_id}: {e}"
+            )
+            return False
+
     async def _resolve_issue_id(self, issue_identifier: str) -> str | None:
         """Resolve issue identifier (like "ENG-842") to full UUID.
 
@@ -776,7 +991,35 @@ class LinearAdapter(BaseAdapter[Task]):
         if task.parent_epic:
             project_id = await self._resolve_project_id(task.parent_epic)
             if project_id:
-                issue_input["projectId"] = project_id
+                # Validate team-project association before assigning
+                is_valid, _ = await self._validate_project_team_association(
+                    project_id, team_id
+                )
+
+                if not is_valid:
+                    # Attempt to add team to project automatically
+                    logging.getLogger(__name__).info(
+                        f"Team {team_id} not associated with project {project_id}. "
+                        f"Attempting to add team to project..."
+                    )
+                    success = await self._ensure_team_in_project(project_id, team_id)
+
+                    if success:
+                        issue_input["projectId"] = project_id
+                        logging.getLogger(__name__).info(
+                            "Successfully associated team with project. "
+                            "Issue will be assigned to project."
+                        )
+                    else:
+                        logging.getLogger(__name__).warning(
+                            "Could not associate team with project. "
+                            "Issue will be created without project assignment. "
+                            "Manual assignment required."
+                        )
+                        issue_input.pop("projectId", None)
+                else:
+                    # Team already associated - safe to assign
+                    issue_input["projectId"] = project_id
             else:
                 # Log warning but don't fail - user may have provided invalid project
                 logging.getLogger(__name__).warning(
@@ -912,13 +1155,29 @@ class LinearAdapter(BaseAdapter[Task]):
         if not project_uuid:
             raise ValueError(f"Project '{epic_id}' not found")
 
+        # Validate field lengths before building update input
+        from mcp_ticketer.core.validators import FieldValidator, ValidationError
+
         # Build update input from updates dict
         update_input = {}
 
         if "title" in updates:
-            update_input["name"] = updates["title"]
+            try:
+                validated_title = FieldValidator.validate_field(
+                    "linear", "epic_name", updates["title"], truncate=False
+                )
+                update_input["name"] = validated_title
+            except ValidationError as e:
+                raise ValueError(str(e)) from e
+
         if "description" in updates:
-            update_input["description"] = updates["description"]
+            try:
+                validated_description = FieldValidator.validate_field(
+                    "linear", "epic_description", updates["description"], truncate=False
+                )
+                update_input["description"] = validated_description
+            except ValidationError as e:
+                raise ValueError(str(e)) from e
         if "state" in updates:
             update_input["state"] = updates["state"]
         if "target_date" in updates:
@@ -973,14 +1232,16 @@ class LinearAdapter(BaseAdapter[Task]):
         except Exception as e:
             raise ValueError(f"Failed to update Linear project: {e}") from e
 
-    async def read(self, ticket_id: str) -> Task | None:
-        """Read a Linear issue by identifier with full details.
+    async def read(self, ticket_id: str) -> Task | Epic | None:
+        """Read a Linear issue OR project by identifier with full details.
 
         Args:
-            ticket_id: Linear issue identifier (e.g., 'BTA-123')
+            ticket_id: Linear issue identifier (e.g., 'BTA-123') or project UUID
 
         Returns:
-            Task with full details or None if not found
+            Task with full details if issue found,
+            Epic with full details if project found,
+            None if not found
 
         """
         # Validate credentials before attempting operation
@@ -988,6 +1249,7 @@ class LinearAdapter(BaseAdapter[Task]):
         if not is_valid:
             raise ValueError(error_message)
 
+        # Try reading as an issue first (most common case)
         query = (
             ALL_FRAGMENTS
             + """
@@ -1006,9 +1268,19 @@ class LinearAdapter(BaseAdapter[Task]):
                 return map_linear_issue_to_task(result["issue"])
 
         except TransportQueryError:
-            # Issue not found
+            # Issue not found, try as project
             pass
 
+        # If not found as issue, try reading as project
+        try:
+            project_data = await self.get_project(ticket_id)
+            if project_data:
+                return map_linear_project_to_epic(project_data)
+        except Exception:
+            # Not found as project either
+            pass
+
+        # Not found as either issue or project
         return None
 
     async def update(self, ticket_id: str, updates: dict[str, Any]) -> Task | None:
@@ -1027,6 +1299,9 @@ class LinearAdapter(BaseAdapter[Task]):
         if not is_valid:
             raise ValueError(error_message)
 
+        # Ensure adapter is initialized (loads workflow states for state transitions)
+        await self.initialize()
+
         # First get the Linear internal ID
         id_query = """
             query GetIssueId($identifier: String!) {
@@ -1694,6 +1969,164 @@ class LinearAdapter(BaseAdapter[Task]):
                 f"Failed to attach file to project '{epic_id}': {e}"
             ) from e
 
+    async def list_cycles(
+        self, team_id: str | None = None, limit: int = 50
+    ) -> builtins.list[dict[str, Any]]:
+        """List Linear Cycles (Sprints) for the team.
+
+        Args:
+            team_id: Linear team UUID. If None, uses the configured team.
+            limit: Maximum number of cycles to return (default: 50)
+
+        Returns:
+            List of cycle dictionaries with fields:
+                - id: Cycle UUID
+                - name: Cycle name
+                - number: Cycle number
+                - startsAt: Start date (ISO format)
+                - endsAt: End date (ISO format)
+                - completedAt: Completion date (ISO format, None if not completed)
+                - progress: Progress percentage (0-1)
+
+        Raises:
+            ValueError: If credentials are invalid or query fails
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        await self.initialize()
+
+        # Use configured team if not specified
+        if team_id is None:
+            team_id = await self._ensure_team_id()
+
+        try:
+            # Fetch all cycles with pagination
+            all_cycles = []
+            has_next_page = True
+            after_cursor = None
+
+            while has_next_page and len(all_cycles) < limit:
+                # Calculate remaining items needed
+                remaining = limit - len(all_cycles)
+                page_size = min(remaining, 50)  # Linear max page size is typically 50
+
+                variables = {"teamId": team_id, "first": page_size}
+                if after_cursor:
+                    variables["after"] = after_cursor
+
+                result = await self.client.execute_query(LIST_CYCLES_QUERY, variables)
+
+                cycles_data = result.get("team", {}).get("cycles", {})
+                page_cycles = cycles_data.get("nodes", [])
+                page_info = cycles_data.get("pageInfo", {})
+
+                all_cycles.extend(page_cycles)
+                has_next_page = page_info.get("hasNextPage", False)
+                after_cursor = page_info.get("endCursor")
+
+            return all_cycles[:limit]  # Ensure we don't exceed limit
+
+        except Exception as e:
+            raise ValueError(f"Failed to list Linear cycles: {e}") from e
+
+    async def get_issue_status(self, issue_id: str) -> dict[str, Any] | None:
+        """Get rich issue status information for a Linear issue.
+
+        Args:
+            issue_id: Linear issue identifier (e.g., 'BTA-123') or UUID
+
+        Returns:
+            Dictionary with workflow state details:
+                - id: State UUID
+                - name: State name (e.g., "In Progress")
+                - type: State type (e.g., "started", "completed")
+                - color: State color (hex format)
+                - description: State description
+                - position: Position in workflow
+            Returns None if issue not found.
+
+        Raises:
+            ValueError: If credentials are invalid or query fails
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        await self.initialize()
+
+        # Resolve issue identifier to UUID if needed
+        issue_uuid = await self._resolve_issue_id(issue_id)
+        if not issue_uuid:
+            return None
+
+        try:
+            result = await self.client.execute_query(
+                GET_ISSUE_STATUS_QUERY, {"issueId": issue_uuid}
+            )
+
+            issue_data = result.get("issue")
+            if not issue_data:
+                return None
+
+            return issue_data.get("state")
+
+        except Exception as e:
+            raise ValueError(f"Failed to get issue status for '{issue_id}': {e}") from e
+
+    async def list_issue_statuses(
+        self, team_id: str | None = None
+    ) -> builtins.list[dict[str, Any]]:
+        """List all workflow states for the team.
+
+        Args:
+            team_id: Linear team UUID. If None, uses the configured team.
+
+        Returns:
+            List of workflow state dictionaries with fields:
+                - id: State UUID
+                - name: State name (e.g., "Backlog", "In Progress", "Done")
+                - type: State type (e.g., "backlog", "unstarted", "started", "completed", "canceled")
+                - color: State color (hex format)
+                - description: State description
+                - position: Position in workflow (lower = earlier)
+
+        Raises:
+            ValueError: If credentials are invalid or query fails
+
+        """
+        # Validate credentials
+        is_valid, error_message = self.validate_credentials()
+        if not is_valid:
+            raise ValueError(error_message)
+
+        await self.initialize()
+
+        # Use configured team if not specified
+        if team_id is None:
+            team_id = await self._ensure_team_id()
+
+        try:
+            result = await self.client.execute_query(
+                LIST_ISSUE_STATUSES_QUERY, {"teamId": team_id}
+            )
+
+            states_data = result.get("team", {}).get("states", {})
+            states = states_data.get("nodes", [])
+
+            # Sort by position to maintain workflow order
+            states.sort(key=lambda s: s.get("position", 0))
+
+            return states
+
+        except Exception as e:
+            raise ValueError(f"Failed to list workflow states: {e}") from e
+
     async def close(self) -> None:
         """Close the adapter and clean up resources."""
         await self.client.close()
